@@ -37,6 +37,24 @@ sub buffer_data {}
 
 sub flush {}
 
+#########
+# BLOCK #
+#########
+
+sub block {
+  my $this = shift ;
+  $this->{BLOCKED} = 1 ;
+}
+
+###########
+# UNBLOCK #
+###########
+
+sub unblock {
+  my $this = shift ;
+  $this->{BLOCKED} = undef ;
+}
+
 #########
 # PRINT #
 #########
@@ -51,6 +69,8 @@ sub print_stdout {
   my $this = shift ;
   my $stdout = $this->{STDOUT} ;
   
+  return if $this->{BLOCKED} ;
+  
   if ( ref($stdout) eq 'SCALAR' ) { $$stdout .= $_[0] ;}
   elsif ( ref($stdout) eq 'CODE' ) {
     my $sel = $Safe_World_NOW->{SELECT}{PREVSTDOUT} ? &Safe::World::SELECT( $Safe_World_NOW->{SELECT}{PREVSTDOUT} ) : undef ;
